ColorComponent

Enum ColorComponent 

#[repr(u8)]
pub enum ColorComponent<ValueType> { None, Value(ValueType), ChannelKeyword(ChannelKeyword), Calc(Box<CalcNode>), AlphaOmitted, }
A single color component.

Variants



None

The “none” keyword.



Value(ValueType)

A absolute value.



ChannelKeyword(ChannelKeyword)

A channel keyword, e.g. r, l, alpha, etc.



Calc(Box<CalcNode>)

A calc() value.



AlphaOmitted

Used when alpha components are not specified.

Implementations

Source

impl<ValueType> ColorComponent<ValueType>

pub fn is_none(&self) -> bool

Return true if the component is “none”.

Source

impl<ValueType: ColorComponentType> ColorComponent<ValueType>

pub fn parse<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, allow_none: bool, allowed_channel_keywords: ChannelKeyword, ) -> Result<Self, ParseError<'i>>

Parse a single ColorComponent.

pub fn to_computed_value( &self, context: Option<&Context<'_>>, origin_color: Option<&AbsoluteColor>, ) -> Self

Compute the component’s value against context, substituting color channel references with the matching channel of origin_color when it is provided (and already converted into this function’s color space).

If no (absolute) origin color is available, channel references are kept intact, so the component can still be resolved later at use-value time.

pub fn resolve(&self) -> Result<Option<ValueType>, ()>

Resolve an already-computed ColorComponent into a float. None is “none”. This assumes color channel references have already been substituted by [to_computed_value], and so does not require an origin color.

Source

impl ColorComponent<NumberOrPercentageComponent>

fn could_be_number(&self) -> bool

Return true if the value contained inside is/can resolve to a number. Also returns false if the node is invalid somehow.

fn could_be_percentage(&self) -> bool

Return true if the value contained inside is/can resolve to a percentage. Also returns false if the node is invalid somehow.